==> rail-0.0.tar.gz: rail-0.0/rail-table-mule.el <==
(defvar rail-mule-version-alist
  '(("KIRITSUBO"      . "$B6MTd(B")
    ("HAHAKIGI"       . "$BVdLZ(B")
    ("UTSUSEMI"       . "$B6u@f(B")
    ("YUUGAO"         . "$BM<4i(B")
    ("WAKAMURASAKI"   . "$B<c;g(B")
    ("SUETSUMUHANA"   . "$BKvE&2V(B")
    ("MOMIJINOGA"     . "$B9HMU2l(B")
    ("HANANOEN"       . "$B2V1c(B")
    ("AOI"            . "$B0*(B")
    ("SAKAKI"         . "$B8-LZ(B")
    ("HANACHIRUSATO"  . "$B2V;6N$(B")
    ("SUMA"           . "$B?\Ka(B")
    ("AKASHI"         . "$BL@@P(B")
    ("MIOTSUKUSHI"    . "$B_:I8(B")
    ("YOMOGIU"        . "$BK)@8(B")
    ("SEKIYA"         . "$B4X20(B")
    ("EAWASE"         . "$B3(9g(B")
    ("MATSUKAZE"      . "$B>>Iw(B")
    ("USUGUMO"        . "$BGv1@(B")
    ("ASAGAO"         . "$BD+4i(B")
    ("OTOME"          . "$B>/=w(B")
    ("TAMAKAZURA"     . "$B6Lr#(B")
    ("HATSUNE"        . "$B=i2;(B")
    ("KOCHOU"         . "$B8UD3(B")
    ("HOTARU"         . "$B7V(B")
    ("TOKONATSU"      . "$B>o2F(B")
    ("KAGARIBI"       . "$Bd@2P(B")
    ("NOWAKE"         . "$BLnJ,(B")
    ("MIYUKI"         . "$B9T9,(B")
    ("FUJIBAKAMA"     . "$BF#8S(B")
    ("MAKIBASHIRA"    . "$B??LZCl(B")
    ("UMEGAE"         . "$BG_;^(B")
    ("FUJINOURABA"    . "$BF#N"MU(B")
    ("WAKANA-KAMI"    . "$B<c:Z>e(B")
    ("WAKANA-SHIMO"   . "$B<c:Z2<(B")
    ("KASHIWAGI"      . "$BGpLZ(B")
    ("YOKOBUE"        . "$B2#E+(B")
    ("SUZUMUSHI"      . "$BNkCn(B")
    ("YUUGIRI"        . "$BM<L8(B")
    ("MINORI"         . "$B8fK!(B")
    ("MABOROSHI"      . "$B88(B")
    ("KUMOGAKURE"     . "$B1@1#(B")
    ("NIOUMIYA"       . "$BFw5\(B")
    ("KOUBAI"         . "$B9HG_(B")
    ("TAKEGAWA"       . "$BC]2O(B")
    ("HASHIHIME"      . "$B66I1(B")
    ("SHIIGAMOTO"     . "$BDGK\(B")
    ("AGEMAKI"        . "$BAm3Q(B")
    ("SAWARABI"       . "$BAaOO(B")
    ("YADORIGI"       . "$B=ILZ(B")
    ("AZUMAYA"        . "$BEl20(B")
    ("UKIFUNE"        . "$BIb=.(B")
    ("KAGEROU"        . "$BiqiY(B")
    ("TENARAI"        . "$B<j=,(B")
    ("YUMENOUKIHASHI" . "$BL4Ib66(B")))

(provide 'rail-mule)

==> rail-0.7.tar.gz: rail-0.7/rail-table-mule.el <==
;; rail-table-mule.el

(defvar rail-mule-codename-alist
  '(("KIRITSUBO"      . "$B6MTd(B")
    ("HAHAKIGI"       . "$BVdLZ(B")
    ("UTSUSEMI"       . "$B6u@f(B")
    ("YUUGAO"         . "$BM<4i(B")
    ("WAKAMURASAKI"   . "$B<c;g(B")
    ("SUETSUMUHANA"   . "$BKvE&2V(B")
    ("MOMIJINOGA"     . "$B9HMU2l(B")
    ("HANANOEN"       . "$B2V1c(B")
    ("AOI"            . "$B0*(B")
    ("SAKAKI"         . "$B8-LZ(B")
    ("HANACHIRUSATO"  . "$B2V;6N$(B")
    ("SUMA"           . "$B?\Ka(B")
    ("AKASHI"         . "$BL@@P(B")
    ("MIOTSUKUSHI"    . "$B_:I8(B")
    ("YOMOGIU"        . "$BK)@8(B")
    ("SEKIYA"         . "$B4X20(B")
    ("EAWASE"         . "$B3(9g(B")
    ("MATSUKAZE"      . "$B>>Iw(B")
    ("USUGUMO"        . "$BGv1@(B")
    ("ASAGAO"         . "$BD+4i(B")
    ("OTOME"          . "$B>/=w(B")
    ("TAMAKAZURA"     . "$B6Lr#(B")
    ("HATSUNE"        . "$B=i2;(B")
    ("KOCHOU"         . "$B8UD3(B")
    ("HOTARU"         . "$B7V(B")
    ("TOKONATSU"      . "$B>o2F(B")
    ("KAGARIBI"       . "$Bd@2P(B")
    ("NOWAKE"         . "$BLnJ,(B")
    ("MIYUKI"         . "$B9T9,(B")
    ("FUJIBAKAMA"     . "$BF#8S(B")
    ("MAKIBASHIRA"    . "$B??LZCl(B")
    ("UMEGAE"         . "$BG_;^(B")
    ("FUJINOURABA"    . "$BF#N"MU(B")
    ("WAKANA-KAMI"    . "$B<c:Z>e(B")
    ("WAKANA-SHIMO"   . "$B<c:Z2<(B")
    ("KASHIWAGI"      . "$BGpLZ(B")
    ("YOKOBUE"        . "$B2#E+(B")
    ("SUZUMUSHI"      . "$BNkCn(B")
    ("YUUGIRI"        . "$BM<L8(B")
    ("MINORI"         . "$B8fK!(B")
    ("MABOROSHI"      . "$B88(B")
    ("KUMOGAKURE"     . "$B1@1#(B")
    ("NIOUMIYA"       . "$BFw5\(B")
    ("KOUBAI"         . "$B9HG_(B")
    ("TAKEGAWA"       . "$BC]2O(B")
    ("HASHIHIME"      . "$B66I1(B")
    ("SHIIGAMOTO"     . "$BDGK\(B")
    ("AGEMAKI"        . "$BAm3Q(B")
    ("SAWARABI"       . "$BAaOO(B")
    ("YADORIGI"       . "$B=ILZ(B")
    ("AZUMAYA"        . "$BEl20(B")
    ("UKIFUNE"        . "$BIb=.(B")
    ("KAGEROU"        . "$BiqiY(B")
    ("TENARAI"        . "$B<j=,(B")
    ("YUMENOUKIHASHI" . "$BL4Ib66(B")))

(provide 'rail-table-mule)
